@@ -6,8 +6,5 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
-#undef HAVE_BONOBO
-#undef USING_OAF
-#undef USING_OLD_OAF
-#undef HAVE_LIBGLADE
 #undef HAVE_GTKHTML
+#undef HAVE_GAL
