@@ -27,8 +27,10 @@ main (int argc, char *argv[])
   gnome_db_init("gnomedb-components", VERSION, argc, argv);
   
   /* register components factory */
-  components_browser_init();
+  components_connection_init();
+  components_designer_init();
   components_export_init();
+  components_help_init();
   components_import_init();
   components_log_init();
   
