@@ -17,6 +17,10 @@
  */
 
 #include "gnome-db.h"
+#include <config.h>
+#if defined(HAVE_GAL)
+#  include <gal/e-paned/e-hpaned.h>
+#endif
 
 static void gnome_db_browser_class_init (GnomeDbBrowserClass *);
 static void gnome_db_browser_init       (GnomeDbBrowser *);
@@ -71,58 +75,56 @@ browse_data_cb (GtkWidget *w, gpointer data)
       gchar *str = 0;
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(brw->tables_button)) ||
 	  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(brw->views_button)))
-	{
-	  str = g_strdup_printf("select * from %s", name);
-	}
+	    {
+	      str = g_strdup_printf("select * from %s", name);
+	    }
           
       if (str != 0)
-	{
-	  GtkWidget *dialog, *frame, *table, *grid, *label, *entry;
-	  gulong reccount;
-	  Gda_Recordset *recset;
-              
-	  dialog = gnome_dialog_new(name, GNOME_STOCK_BUTTON_CLOSE, NULL);
-	  gtk_widget_set_usize(dialog, 600, 450);
-          frame = gnome_db_new_frame_widget(NULL);
-	  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, 1, 1, 0);
-              
-	  table = gtk_table_new(4, 2, FALSE);
-	  gtk_widget_show(table);
-          gtk_container_add(GTK_CONTAINER(frame), table);
-
-          label = gnome_db_new_label_widget(_("Object Name"));
-	  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-                           GTK_FILL,
-                           GTK_FILL,
-			       3, 3);
+        {
+          GtkWidget *dialog, *frame, *table, *grid, *label, *entry;
+          gulong reccount;
+          Gda_Recordset *recset;
           
-          entry = gnome_db_new_entry_widget(0, FALSE);
-	  gtk_entry_set_text(GTK_ENTRY(entry), name);
-	  gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 0, 1,
-			       GTK_FILL,
+          dialog = gnome_dialog_new(name, GNOME_STOCK_BUTTON_CLOSE, NULL);
+          gtk_widget_set_usize(dialog, 600, 450);
+          frame = gnome_db_new_frame_widget(NULL);
+          gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, 1, 1, 0);
+          
+          table = gtk_table_new(4, 2, FALSE);
+          gtk_widget_show(table);
+          gtk_container_add(GTK_CONTAINER(frame), table);
+          
+          label = gnome_db_new_label_widget(_("Object Name"));
+          gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
                            GTK_FILL,
-			       3, 3);
-
-	  grid = gnome_db_new_grid_widget(NULL);
+                           GTK_FILL,
+                           3, 3);
+                           
+          entry = gnome_db_new_entry_widget(0, FALSE);
+          gtk_entry_set_text(GTK_ENTRY(entry), name);
+          gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
+          
+          grid = gnome_db_new_grid_widget(NULL);
           gtk_table_attach(GTK_TABLE(table), grid, 0, 2, 1, 3,
                            GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                            GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                            3, 3);
 
-	  label = gnome_db_new_label_widget(_("0 rows"));
-	  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+          label = gnome_db_new_label_widget(_("0 rows"));
+          gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
           gtk_table_attach(GTK_TABLE(table), label, 0, 2, 3, 4, GTK_FILL, GTK_FILL, 3, 3);
-	  gtk_signal_connect(GTK_OBJECT(grid), "loaded",
-			     GTK_SIGNAL_FUNC(browse_data_loaded_cb), (gpointer) label);
-              
-	  /* show recordset */
-	  recset = gda_connection_execute(brw->cnc, str, &reccount, 0);
-	  gnome_db_grid_set_recordset(GNOME_DB_GRID(grid), recset);
-	  
-	  gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
-              
-	  g_free((gpointer) str);
-	}
+          gtk_signal_connect(GTK_OBJECT(grid),
+                             "loaded",
+                             GTK_SIGNAL_FUNC(browse_data_loaded_cb),
+                             (gpointer) label);
+          
+          /* show recordset */
+          recset = gda_connection_execute(brw->cnc, str, &reccount, 0);
+          gnome_db_grid_set_recordset(GNOME_DB_GRID(grid), recset);
+          
+          gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
+          g_free((gpointer) str);
+        }
     }
 }
 
@@ -163,8 +165,8 @@ extra_info_cb (GtkWidget *w, gpointer data)
           recset = gda_connection_open_schema(brw->cnc,
                                               GDA_Connection_GDCN_SCHEMA_TABLES,
                                               GDA_Connection_EXTRA_INFO,
-					      "",
-					      GDA_Connection_OBJECT_NAME,
+                                              "",
+                                              GDA_Connection_OBJECT_NAME,
                                               name,
                                               GDA_Connection_no_CONSTRAINT);
         }
@@ -204,8 +206,20 @@ extra_info_cb (GtkWidget *w, gpointer data)
                                               name,
                                               GDA_Connection_no_CONSTRAINT);
         }
-      gnome_db_grid_set_recordset(GNOME_DB_GRID(brw->object_description),
-                                  recset);
+      
+      /* show object properties */
+      if (IS_GDA_RECORDSET(recset))
+        {
+          GtkWidget* dialog;
+          GtkWidget* dataset;
+          
+          dialog = gnome_dialog_new(_("Object properties"), GNOME_STOCK_BUTTON_CLOSE, NULL);
+          dataset = gnome_db_dataset_new(recset);
+          gtk_widget_show(dataset);
+          gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), dataset, 1, 1, 0);
+          gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
+          gda_recordset_free(recset);
+        }
     }
 }
 
@@ -397,15 +411,26 @@ gnome_db_browser_class_init (GnomeDbBrowserClass *klass)
 static void
 gnome_db_browser_init (GnomeDbBrowser *brw)
 {
-  GtkWidget *frame;
+  //GtkWidget *frame;
   GtkWidget *table;
   GtkWidget *box;
   GtkWidget *button;
-  
-  frame = gnome_db_new_frame_widget(NULL);
-  gtk_box_pack_start(GTK_BOX(brw), frame, 1, 1, 0);
-  table = gtk_table_new(6, 4, FALSE);
-  gtk_container_add(GTK_CONTAINER(frame), table);
+  GtkWidget *paned;
+
+#if defined(HAVE_GAL)
+  paned = e_hpaned_new();
+#else
+  paned = gtk_hpaned_new();
+#endif
+  gtk_box_pack_start(GTK_BOX(brw), paned, 1, 1, 0);
+  gtk_widget_show(paned);
+
+  table = gtk_table_new(3, 4, FALSE);
+#if defined(HAVE_GAL)
+  e_paned_add2(E_PANED(paned), table);
+#else
+  gtk_paned_add2(GTK_PANED(paned), table);
+#endif
   gtk_widget_show(table);
   
   brw->object_list = gnome_db_list_new(0, 0);
@@ -416,13 +441,14 @@ gnome_db_browser_init (GnomeDbBrowser *brw)
   gtk_signal_connect(GTK_OBJECT(brw->object_list), "select_row",
                      GTK_SIGNAL_FUNC(select_object_cb), (gpointer) brw);
   gtk_widget_show(brw->object_list);
-  gtk_table_attach(GTK_TABLE(table), brw->object_list, 0, 3, 0, 5,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   GTK_FILL,
-                   3, 3);
+#if defined(HAVE_GAL)
+  e_paned_add1(E_PANED(paned), brw->object_list);
+#else
+  gtk_paned_add1(GTK_PANED(paned), brw->object_list);
+#endif
 
   brw->object_description = gnome_db_new_grid_widget(NULL);
-  gtk_table_attach(GTK_TABLE(table), brw->object_description, 3, 6, 1, 4,
+  gtk_table_attach(GTK_TABLE(table), brw->object_description, 0, 3, 1, 4,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    3, 3);
@@ -467,13 +493,13 @@ gnome_db_browser_init (GnomeDbBrowser *brw)
   gtk_widget_show(brw->aggrs_button);
   gtk_box_pack_start(GTK_BOX(box), brw->aggrs_button, 0, 0, 0);
   
-  gtk_table_attach(GTK_TABLE(table), box, 3, 6, 0, 1, GTK_FILL, GTK_FILL, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), box, 0, 3, 0, 1, GTK_FILL, GTK_FILL, 1, 1);
   gtk_widget_show(box);
   
   /* create button bar */
   box = gtk_hbox_new(TRUE, 0);
   gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 3, 6, 4, 5, GTK_FILL, GTK_FILL, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), box, 0, 3, 4, 5, GTK_FILL, GTK_FILL, 1, 1);
                    
   button = gnome_pixmap_button(gnome_stock_new_with_icon(GNOME_STOCK_MENU_PROP),
                                _("Data"));
