@@ -18,12 +18,27 @@
  
 #include "gnome-db.h"
 #include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-print-dialog.h>
 #include <libgnomeprint/gnome-printer.h>
 #include <libgnomeprint/gnome-printer-dialog.h>
 
+static GnomePrinter* default_printer = NULL;
+
 void
 gnome_db_print_setup_dlg_cb (GtkWidget *w, gpointer data)
 {
-  GtkWidget *dialog = gnome_printer_dialog_new();
-  gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
+  GtkWidget *dialog = gnome_print_dialog_new(_("Setup Printer"), 0);
+  gnome_dialog_set_default(GNOME_DIALOG(dialog), GNOME_PRINT_PRINT);
+  if (gnome_dialog_run(GNOME_DIALOG(dialog)) == GNOME_PRINT_PRINT)
+    {
+      default_printer = gnome_print_dialog_get_printer(GNOME_PRINT_DIALOG(dialog));
+    }
+  gnome_dialog_close(GNOME_DIALOG(dialog));
 }
+
+GnomePrinter *
+gnome_db_print_get_printer (void)
+{
+  if (!default_printer) gnome_db_print_setup_dlg_cb(NULL, NULL);
+  return default_printer;
+}
\ No newline at end of file
