@@ -264,6 +264,18 @@ gnome_db_new_option_menu_widget (void)
   return option_menu;
 }
 
+GtkWidget *
+gnome_db_new_progress_bar_widget (void)
+{
+  GtkWidget* progress_bar;
+  
+  progress_bar = gtk_progress_bar_new();
+  gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(progress_bar), GTK_PROGRESS_LEFT_TO_RIGHT);
+  gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(progress_bar), GTK_PROGRESS_CONTINUOUS);
+  gtk_widget_show(progress_bar);
+  return progress_bar;
+}
+
 GtkWidget *
 gnome_db_new_radio_button_widget (const gchar *label, GtkRadioButton *group)
 {
@@ -288,6 +300,15 @@ gnome_db_new_scrolled_window_widget (void)
   return (scrolled_window);
 }
 
+GtkWidget *
+gnome_db_new_status_bar_widget (void)
+{
+  GtkWidget* status;
+  status = gtk_statusbar_new();
+  gtk_widget_show(status);
+  return status;
+}
+
 GtkWidget *
 gnome_db_new_table_widget (guint cols, guint rows, gboolean homogenous)
 {
@@ -392,7 +413,7 @@ void
 gnome_db_show_about_dialog (const gchar *title)
 {
   const gchar *authors[] = { "Michael Lausch <michael@lausch.at>",
-                             "Rodrigo Moya <rodrigo@linuxave.net>",
+                             "Rodrigo Moya <rodrigo@gnome-db.org>",
                              "Stephan Heinze <stephan.heinze@xcom.de>",
                              "Vivien Malerba <malerba@linuxave.net>",
 			              "Nick Gorham <nick@lurcher.org>",
@@ -400,6 +421,8 @@ gnome_db_show_about_dialog (const gchar *title)
 			              "Alvaro del Castillo <acs@futurnet.es>",
                              "Akira TAGOH <tagoh@gnome.gr.jp>",
                              "Carlos Perell Marn <carlos@hispalinux.es>",
+                             "Holger Thon <holger@gidayu.max.uni-duisburg.de>",
+                             "Joaqun Cuenca <e98cuenc@yahoo.com>",
                              NULL };
   GtkWidget *about = gnome_about_new(title, VERSION,
 	     _("Copyright The Free Software Foundation (C) 1998-2000"),
@@ -459,7 +482,14 @@ gnome_db_set_bg_color (GtkWidget *w, gint red, gint green, gint blue)
   color.blue = blue;
   if (gdk_color_alloc(colormap, &color))
     {
+      GtkStyle *style, *style_default;
+
+      style_default = gtk_widget_get_default_style();
+      style = gtk_style_copy(style_default);
+      style->base[GTK_STATE_NORMAL] = color;
+      gtk_widget_set_style(w, style);
     }
+  else g_warning(_("Could not allocate color"));
 }
 
 static gint
@@ -501,10 +531,10 @@ gnome_db_load_window_config (const gchar *name, GtkWidget *window)
   gdk_window_move(window->window,
                   get_config_int("/%s/Placement/%s_X",
                                  g_get_prgname(),
-                                 name),
+                                 name) + 20,
                   get_config_int("/%s/Placement/%s_Y",
                                  g_get_prgname(),
-                                 name));
+                                 name) + 20);
   gtk_widget_set_usize(window,
                        get_config_int("/%s/Placement/%s_Width",
                                       g_get_prgname(),
