@@ -20,6 +20,9 @@
 #  define __gnomedb_rolodex_h__
 
 #include <gnome-db.h>
+#if defined(HAVE_CONFIG_H)
+#  include <config.h>
+#endif
 
 /*
  * Callbacks
